pub struct DeclarationInspectionFields {
pub source: bool,
pub statement: bool,
pub docstring: bool,
pub attributes: bool,
pub flags: bool,
pub statement_pretty: bool,
pub proof_search: bool,
}Fields
source: boolstatement: booldocstring: boolattributes: boolflags: boolstatement_pretty: boolRender statement notation-aware (pp.universes false) when true,
falling back to the raw term if the pretty-printer cannot render it;
the fully-elaborated raw form when false.
proof_search: boolInclude proof-search-oriented facts such as simp/rw/instance/class. Defaults off because these facts may touch persistent extensions and lazy derived search indexes.